geom_smooth is a function that provides additional
functionality to the standard
geom_smooth function in the event
that it is being used on a ggtern object.
Parameters are the same, with the exception of the
introduction of the limitarea parameter.geom_smooth(mapping = NULL, data = NULL,
stat = "smoothtern", position = "identity",
limitarea = TRUE, fullrange = FALSE, ...)TRUE, the value of
fullrange has no meaning, since the full-range
becomes essentially becomes limited by thaes or aes_string. Only
needs to be set at the layer level if you are overriding
the plot defaults.