Learn R Programming

ggtern (version 3.4.2)

theme_complete: List of Available Themes

Description

ggtern ships with a number of complete themes, summarized as follows. These themes combine the base themes available to ggplot2 and a number of NEW themes, which are unique to ggtern.

  • Black and White Theme: theme_bw(...)

  • Minimal Theme: theme_minimal(...)

  • Classic Theme: theme_classic(...)

  • Gray and White Theme: theme_gray(...)

  • Red, Green, Blue and White Theme: theme_rgbw(...)

  • Red, Green, Blue and Gray Theme: theme_rgbg(...)

  • Dark Theme: theme_dark(...)

  • Darker Theme: theme_darker(...)

  • Light Theme: theme_light(...)

  • Theme with Only Black Lines: theme_linedraw(...)

  • Matrix Theme: theme_matrix(...)

  • Tropical Theme: theme_tropical(...)

  • BlueLight Theme: theme_bluelight(...)

  • BlueDark Theme: theme_bluedark(...)

  • Black Vermillion Blue Theme (White Background): theme_bvbw(...)

  • Black Vermillion Blue Theme (Grey Background): theme_bvbg(...)

Arguments

Author

Nicholas Hamilton

See Also

ggtern_themes