Convenience Function to Show or Hide the Clipping Mask, theme_showmask is a function that
appends to the current theme a flag to switch ON the clipping mask, whilst, theme_nomask (or theme_hidemask) is a function
that appends to the current theme a flag to switch OFF the clipping mask
1 2 3 4 5 |
Nicholas Hamilton
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.