View source: R/theme-ticksoutside.R
theme_ticksoutside is a function that ensures the ticks are placed OUTSIDE of the plot area, whereas,
theme_ticksinside is a function that ensures the ticks are placed INSIDE of the plot area
(opposite to theme_ticksoutside)
1 2 3 |
Nicholas Hamilton
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.